==> comPaginate.1.0.1.zip: comPaginate/comPaginate.php <==
<?php if(!defined('PLX_ROOT')) exit;
	/**
		* Plugin 			comPaginate
		*
		* @CMS required			PluXml 
		*
		* @version			1.0
		* @date				2025-01-04
		* @author 			G-cyrillus
		░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░
		░       ░░  ░░░░░░░  ░░░░  ░  ░░░░  ░░      ░░       ░░░      ░░  ░░░░░░░        ░░      ░░░░░   ░░░  ░        ░        ░
		▒  ▒▒▒▒  ▒  ▒▒▒▒▒▒▒  ▒▒▒▒  ▒▒  ▒▒  ▒▒  ▒▒▒▒  ▒  ▒▒▒▒  ▒  ▒▒▒▒  ▒  ▒▒▒▒▒▒▒▒▒▒  ▒▒▒▒  ▒▒▒▒▒▒▒▒▒▒    ▒▒  ▒  ▒▒▒▒▒▒▒▒▒▒  ▒▒▒▒
		▓       ▓▓  ▓▓▓▓▓▓▓  ▓▓▓▓  ▓▓▓    ▓▓▓  ▓▓▓▓  ▓       ▓▓  ▓▓▓▓  ▓  ▓▓▓▓▓▓▓▓▓▓  ▓▓▓▓▓      ▓▓▓▓▓  ▓  ▓  ▓      ▓▓▓▓▓▓  ▓▓▓▓
		█  ███████  ███████  ████  ██  ██  ██  ████  █  ███████  ████  █  ██████████  ██████████  ████  ██    █  ██████████  ████
		█  ███████        ██      ██  ████  ██      ██  ████████      ██        █        ██      ██  █  ███   █        ████  ████
		█████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████
	**/
	class comPaginate extends plxPlugin {
		
		
		
		const BEGIN_CODE = '<?php' . PHP_EOL;
		const END_CODE = PHP_EOL . '?>';
		public $lang = ''; 
		public $nbcom;
		
		
		public function __construct($default_lang) {
			# appel du constructeur de la classe plxPlugin (obligatoire)
			parent::__construct($default_lang);
			
			
			
			# droits pour accèder à la page config.php du plugin
			$this->setConfigProfil(PROFIL_ADMIN, PROFIL_MANAGER);		
			$numeric101 = $this->getParam('numeric101') ==''   ?   '0' : $this->getParam('numeric101') ;
			
			
			# Declaration des hooks		
			$this->addHook('AdminTopBottom', 'AdminTopBottom');
			$this->addHook('ThemeEndHead', 'ThemeEndHead');
			$this->addHook('IndexBegin', 'IndexBegin');
			
			$this->nbcom  = $this->getParam('nbcom')  ==''   ?   50 : $this->getParam('nbcom') ;
			
		}
		
		# Activation / desactivation
		
		public function OnActivate() {
			# code à executer à l’activation du plugin
			//nowizards set
		}
		
		public function OnDeactivate() {
			# code à executer à la désactivation du plugin
		}	
		
		
		public function ThemeEndHead() {
			#gestion multilingue
			if(defined('PLX_MYMULTILINGUE')) {		
				$plxMML = is_array(PLX_MYMULTILINGUE) ? PLX_MYMULTILINGUE : unserialize(PLX_MYMULTILINGUE);
				$langues = empty($plxMML['langs']) ? array() : explode(',', $plxMML['langs']);
				$string = '';
				foreach($langues as $k=>$v)	{
					$url_lang="";
					if($_SESSION['default_lang'] != $v) $url_lang = $v.'/';
					$string .= 'echo "\\t<link rel=\\"alternate\\" hreflang=\\"'.$v.'\\" href=\\"".$plxMotor->urlRewrite("?'.$url_lang.$this->getParam('url').'")."\" />\\n";';
				}
				echo '<?php if($plxMotor->mode=="'.$this->getParam('url').'") { '.$string.'} ?>';
			}
			
			
			// ajouter ici vos propre codes (insertion balises link, script , ou autre)
		}
		
		/**
			* Méthode qui affiche un message si le plugin n'a pas la langue du site dans sa traduction
			* Ajout gestion du wizard si inclus au plugin
			* @return	stdio
			* @author	Stephane F
		**/
		public function AdminTopBottom() {
			
			echo '<?php
			$file = PLX_PLUGINS."'.$this->plug['name'].'/lang/".$plxAdmin->aConf["default_lang"].".php";
			if(!file_exists($file)) {
			echo "<p class=\\"warning\\">'.basename(__DIR__).'<br />".sprintf("'.$this->getLang('L_LANG_UNAVAILABLE').'", $file)."</p>";
			plxMsg::Display();
			}
			?>';
		}
		
		/** 
			* Méthode Index
			* 
			* Descrition	:
			* @author		: TheCrok
			* 
		**/
		public function IndexBegin() {
			# code à executer
			echo self::BEGIN_CODE;
		?>
		$navCom ='';
		$comNum = intval($plxMotor->plxRecord_arts->f('nb_com'));
		if($plxMotor->mode =='article'  && $comNum > <?= $this->nbcom ?> ) {
		
		#  combien de pages
		$nbPages = ceil($comNum / <?= $this->nbcom ?> );

		# quelle page 
		$page = $plxMotor->get;
		if (preg_match('/(\/?page[0-9]+)$/', $page, $capture)) {
		$page = substr($capture[1],5,3);
		}
		else $page=1;
		# quels commentaires à extraire ?
		if($page ==1) {$first = 0; ;}
		else $first= (<?= $this->nbcom ?> * intval($page)) - <?= $this->nbcom ?>;
		$end = $first + <?= $this->nbcom ?>;
		
		# extraction des commentaires de la page
		$plxMotor->getCommentaires('#^'.$plxMotor->cible.'.\d{10}-\d+.xml$#',$plxMotor->tri_coms,$first,<?= $this->nbcom ?>,'before');

		#creation de la pagination 
		
		$navCom.='<nav class="pagination text-center nav comments" style="display:flex;width:max-content;margin:1em auto;align-items:center;border:solid 1px;border-radius:5px;gap:0.5em;padding:0.5em;">'.PHP_EOL;
		# extraction de l'url
		$url = $plxShow->plxMotor->urlRewrite('?article' . $plxShow->plxMotor->plxRecord_arts->f('numero') . '/' . $plxShow->plxMotor->plxRecord_arts->f('url') );
		$link = $plxShow->plxMotor->urlRewrite($url."/page");
		$prev=$next=$page;
		if($page > 2 && $nbPages > 2) $navCom .='<a href="'.$link.'#comments"  title="' . L_PAGINATION_FIRST_TITLE . '"> &lt;&lt; </a> '.PHP_EOL;
		if($page > 1) $navCom .='<a href="'.$link.--$prev.'#comments" title="' . L_PAGINATION_PREVIOUS_TITLE . '">page '.$prev.'</a> '.PHP_EOL;
		$navCom .='<span>page '.$page.' / '.$nbPages.'</span>'.PHP_EOL;
		if($page < $nbPages && $page != $nbPages) $navCom .='<a href="'.$link.++$next.'#comments" title="' . L_PAGINATION_NEXT_TITLE . '">page '.$next.'</a> '.PHP_EOL;
		if($page < $nbPages && $nbPages > 2 ) $navCom .='<a href="'.$link.$nbPages.'#comments"  title="' . L_PAGINATION_LAST_TITLE . '"> &gt;&gt;</a> '.PHP_EOL;
		$navCom .='</nav>'.PHP_EOL;

		}
		$plxShow->plxMotor->aConf['comNav'] = $navCom;
		<?php
			echo self::END_CODE;			
			
		}

	}

==> comPaginate.1.0.2.zip: comPaginate/comPaginate.php <==
<?php if(!defined('PLX_ROOT')) exit;
	/**
		* Plugin 			comPaginate
		*
		* @CMS required			PluXml 
		*
		* @version			1.0.2
		* @date				05/01/2024
		* @author 			G-cyrillus
		░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░
		░       ░░  ░░░░░░░  ░░░░  ░  ░░░░  ░░      ░░       ░░░      ░░  ░░░░░░░        ░░      ░░░░░   ░░░  ░        ░        ░
		▒  ▒▒▒▒  ▒  ▒▒▒▒▒▒▒  ▒▒▒▒  ▒▒  ▒▒  ▒▒  ▒▒▒▒  ▒  ▒▒▒▒  ▒  ▒▒▒▒  ▒  ▒▒▒▒▒▒▒▒▒▒  ▒▒▒▒  ▒▒▒▒▒▒▒▒▒▒    ▒▒  ▒  ▒▒▒▒▒▒▒▒▒▒  ▒▒▒▒
		▓       ▓▓  ▓▓▓▓▓▓▓  ▓▓▓▓  ▓▓▓    ▓▓▓  ▓▓▓▓  ▓       ▓▓  ▓▓▓▓  ▓  ▓▓▓▓▓▓▓▓▓▓  ▓▓▓▓▓      ▓▓▓▓▓  ▓  ▓  ▓      ▓▓▓▓▓▓  ▓▓▓▓
		█  ███████  ███████  ████  ██  ██  ██  ████  █  ███████  ████  █  ██████████  ██████████  ████  ██    █  ██████████  ████
		█  ███████        ██      ██  ████  ██      ██  ████████      ██        █        ██      ██  █  ███   █        ████  ████
		█████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████
	**/
	class comPaginate extends plxPlugin {	
		
		const BEGIN_CODE = '<?php' . PHP_EOL;
		const END_CODE = PHP_EOL . '?>';
		public $lang = ''; 
		public $nbcom;		
		
		public function __construct($default_lang) {
			# appel du constructeur de la classe plxPlugin (obligatoire)
			parent::__construct($default_lang);
			
			
			
			# droits pour accèder à la page config.php du plugin
			$this->setConfigProfil(PROFIL_ADMIN, PROFIL_MANAGER);			
			
			# Declaration des hooks		
			$this->addHook('AdminTopBottom', 'AdminTopBottom');
			$this->addHook('ThemeEndHead', 'ThemeEndHead');
			$this->addHook('IndexBegin', 'IndexBegin');
			
			$this->nbcom  = $this->getParam('nbcom')  ==''   ?   50 : $this->getParam('nbcom') ;
		}
		
		
		public function ThemeEndHead() {
			#gestion multilingue
			if(defined('PLX_MYMULTILINGUE')) {		
				$plxMML = is_array(PLX_MYMULTILINGUE) ? PLX_MYMULTILINGUE : unserialize(PLX_MYMULTILINGUE);
				$langues = empty($plxMML['langs']) ? array() : explode(',', $plxMML['langs']);
				$string = '';
				foreach($langues as $k=>$v)	{
					$url_lang="";
					if($_SESSION['default_lang'] != $v) $url_lang = $v.'/';
					$string .= 'echo "\\t<link rel=\\"alternate\\" hreflang=\\"'.$v.'\\" href=\\"".$plxMotor->urlRewrite("?'.$url_lang.$this->getParam('url').'")."\" />\\n";';
				}
				echo '<?php if($plxMotor->mode=="'.$this->getParam('url').'") { '.$string.'} ?>';
			}
		}
		
		/**
			* Méthode qui affiche un message si le plugin n'a pas la langue du site dans sa traduction
			* Ajout gestion du wizard si inclus au plugin
			* @return	stdio
			* @author	Stephane F
		**/
		public function AdminTopBottom() {
			
			echo '<?php
			$file = PLX_PLUGINS."'.$this->plug['name'].'/lang/".$plxAdmin->aConf["default_lang"].".php";
			if(!file_exists($file)) {
			echo "<p class=\\"warning\\">'.basename(__DIR__).'<br />".sprintf("'.$this->getLang('L_LANG_UNAVAILABLE').'", $file)."</p>";
			plxMsg::Display();
			}
			?>';
		}
		
		/** 
			* Méthode IndexBegin
			* 
			* Descrition	:
			* @author		: TheCrok
			* 
		**/
		public function IndexBegin() {
			# code à executer
			echo self::BEGIN_CODE;
		?>		
		$navCom ='';
		if($plxMotor->mode =='article')	$comNum = intval($plxMotor->plxRecord_arts->f('nb_com'));
		if($plxMotor->mode =='article'  && $comNum > <?= $this->nbcom ?> ) {
			#  combien de pages
			$nbPages = ceil($comNum / <?= $this->nbcom ?> );

			# quelle page 
			$page = $plxMotor->get;
			if (preg_match('/(\/?page[0-9]+)$/', $page, $capture)) {
				$page = substr($capture[1],5,3);
			}
			else $page=1;
			# quels commentaires à extraire ?
			if($page ==1) {$first = 0; ;}
			else $first= (<?= $this->nbcom ?> * intval($page)) - <?= $this->nbcom ?>;
			$end = $first + <?= $this->nbcom ?>;
			$plxMotor->getCommentaires('#^'.$plxMotor->cible.'.\d{10}-\d+.xml$#',$plxMotor->tri_coms,$first,<?= $this->nbcom ?>,'before');

			#creation de la pagination 
			$navCom.='<nav class="pagination text-center nav comments" style="display:flex;width:max-content;margin:1em auto;align-items:center;border:solid 1px;border-radius:5px;gap:0.5em;padding:0.5em;">'.PHP_EOL;
			# extraction de l'url
			$url = $plxShow->plxMotor->urlRewrite('?article' . $plxShow->plxMotor->plxRecord_arts->f('numero') . '/' . $plxShow->plxMotor->plxRecord_arts->f('url') );
			$link = $plxShow->plxMotor->urlRewrite($url."/page");
			$prev=$next=$page;
			if($page > 2 && $nbPages > 2) $navCom .='<a href="'.$link.'#comments"  title="' . L_PAGINATION_FIRST_TITLE . '"> &lt;&lt; </a> '.PHP_EOL;
			if($page > 1) $navCom .='<a href="'.$link.--$prev.'#comments" title="' . L_PAGINATION_PREVIOUS_TITLE . '">page '.$prev.'</a> '.PHP_EOL;
			$navCom .='<span>page '.$page.' / '.$nbPages.'</span>'.PHP_EOL;
			if($page < $nbPages && $page != $nbPages) $navCom .='<a href="'.$link.++$next.'#comments" title="' . L_PAGINATION_NEXT_TITLE . '">page '.$next.'</a> '.PHP_EOL;
			if($page < $nbPages && $nbPages > 2 ) $navCom .='<a href="'.$link.$nbPages.'#comments"  title="' . L_PAGINATION_LAST_TITLE . '"> &gt;&gt;</a> '.PHP_EOL;
			$navCom .='</nav>'.PHP_EOL;
		}
		$plxShow->plxMotor->aConf['comNav'] = $navCom;
		<?php
			echo self::END_CODE;				
		}
	}
